EXPORTS
	??0TOverlayParameters@CCameraOverlay@CCamera@@QAE@XZ @ 1 NONAME ; CCamera::CCameraOverlay::TOverlayParameters::TOverlayParameters(void)
	??0TOverlaySupportInfo@CCameraOverlay@CCamera@@QAE@XZ @ 2 NONAME ; CCamera::CCameraOverlay::TOverlaySupportInfo::TOverlaySupportInfo(void)
	??1CCameraOverlay@CCamera@@UAE@XZ @ 3 NONAME ; CCamera::CCameraOverlay::~CCameraOverlay(void)
	?CreateOverlayL@CCameraOverlay@CCamera@@QAEIABVTOverlayParameters@12@PAVCFbsBitmap@@@Z @ 4 NONAME ; unsigned int CCamera::CCameraOverlay::CreateOverlayL(class CCamera::CCameraOverlay::TOverlayParameters const &, class CFbsBitmap *)
	?GetAllOverlaysInZOrderL@CCameraOverlay@CCamera@@QAEXAAV?$RArray@I@@@Z @ 5 NONAME ; void CCamera::CCameraOverlay::GetAllOverlaysInZOrderL(class RArray<unsigned int> &)
	?GetAllOverlaysL@CCameraOverlay@CCamera@@QAEXAAV?$RArray@I@@@Z @ 6 NONAME ABSENT
	?GetOverlayBitmapL@CCameraOverlay@CCamera@@QAEXIPAVCFbsBitmap@@@Z @ 7 NONAME ; void CCamera::CCameraOverlay::GetOverlayBitmapL(unsigned int, class CFbsBitmap *)
	?GetOverlayParametersL@CCameraOverlay@CCamera@@QAEXIAAVTOverlayParameters@12@@Z @ 8 NONAME ; void CCamera::CCameraOverlay::GetOverlayParametersL(unsigned int, class CCamera::CCameraOverlay::TOverlayParameters &)
	?GetOverlaySupport@CCameraOverlay@CCamera@@QAEXAAVTOverlaySupportInfo@12@@Z @ 9 NONAME ; void CCamera::CCameraOverlay::GetOverlaySupport(class CCamera::CCameraOverlay::TOverlaySupportInfo &)
	?NewL@CCameraOverlay@CCamera@@SAPAV12@AAV2@@Z @ 10 NONAME ; class CCamera::CCameraOverlay * CCamera::CCameraOverlay::NewL(class CCamera &)
	?ReleaseOverlay@CCameraOverlay@CCamera@@QAEXI@Z @ 11 NONAME ; void CCamera::CCameraOverlay::ReleaseOverlay(unsigned int)
	?SetAllOverlaysInZOrderL@CCameraOverlay@CCamera@@QAEXABV?$RArray@I@@@Z @ 12 NONAME ; void CCamera::CCameraOverlay::SetAllOverlaysInZOrderL(class RArray<unsigned int> const &)
	?SetOverlayBitmapL@CCameraOverlay@CCamera@@QAEXIPBVCFbsBitmap@@@Z @ 13 NONAME ; void CCamera::CCameraOverlay::SetOverlayBitmapL(unsigned int, class CFbsBitmap const *)
	?SetOverlayParametersL@CCameraOverlay@CCamera@@QAEXIABVTOverlayParameters@12@@Z @ 14 NONAME ; void CCamera::CCameraOverlay::SetOverlayParametersL(unsigned int, class CCamera::CCameraOverlay::TOverlayParameters const &)
	?GetAllOverlaysInZOrderL@CCameraOverlay@CCamera@@QBEXW4TOverlayCameraMode@12@HAAV?$RArray@I@@@Z @ 15 NONAME ; void CCamera::CCameraOverlay::GetAllOverlaysInZOrderL(enum CCamera::CCameraOverlay::TOverlayCameraMode, int, class RArray<unsigned int> &) const
	?SetAllOverlaysInZOrderL@CCameraOverlay@CCamera@@QAEXW4TOverlayCameraMode@12@HABV?$RArray@I@@@Z @ 16 NONAME ; void CCamera::CCameraOverlay::SetAllOverlaysInZOrderL(enum CCamera::CCameraOverlay::TOverlayCameraMode, int, class RArray<unsigned int> const &)
	?SetModifiableOverlayBitmapL@CCameraOverlay@CCamera@@QAEXIPAVCFbsBitmap@@@Z @ 17 NONAME ; void CCamera::CCameraOverlay::SetModifiableOverlayBitmapL(unsigned int, class CFbsBitmap *)
	?Size@TOverlayParameters@CCameraOverlay@CCamera@@QBEIXZ @ 18 NONAME ; unsigned int CCamera::CCameraOverlay::TOverlayParameters::Size(void) const
	?Size@TOverlaySupportInfo@CCameraOverlay@CCamera@@QBEIXZ @ 19 NONAME ; unsigned int CCamera::CCameraOverlay::TOverlaySupportInfo::Size(void) const
	?Version@TOverlayParameters@CCameraOverlay@CCamera@@QBEIXZ @ 20 NONAME ; unsigned int CCamera::CCameraOverlay::TOverlayParameters::Version(void) const
	?Version@TOverlaySupportInfo@CCameraOverlay@CCamera@@QBEIXZ @ 21 NONAME ; unsigned int CCamera::CCameraOverlay::TOverlaySupportInfo::Version(void) const

